package cn.com.qmth.examcloud.core.oe.student.service;

import java.util.List;

import cn.com.qmth.examcloud.core.oe.common.entity.*;
import cn.com.qmth.examcloud.core.oe.common.enums.ExamRecordStatus;
import cn.com.qmth.examcloud.core.oe.common.enums.ExamType;
import cn.com.qmth.examcloud.core.oe.student.bean.CalculateFaceCheckResultInfo;
import cn.com.qmth.examcloud.examwork.api.bean.ExamBean;

/**
 * @author chenken
 * @date 2018/8/15 11:16
 * @company QMTH
 * @description 考试记录数据服务接口
 */
public interface ExamRecordDataService {
	
	/**
	 * 创建ExamRecordDataEntity
	 * @param examRecordEntity
	 * @return
	 */
	ExamRecordDataEntity createExamRecordData(ExamRecordEntity examRecordEntity, ExamStudentEntity examStudentEntity, ExamBean examBean, boolean isFullyObjetive);

    List<ExamRecordDataEntity> findByStatusAndExamTypeIn(ExamRecordStatus examRecordStatus, List<String> examTypeList);
    
    /**
     * 根据考生ID查询所有有效考试记录
     * @param examStudentId
     * @return
     */
	List<ExamRecordDataEntity> findValidExamRecordDataByExamStudentId(Long examStudentId);
    
    /**
     * 计算人脸检测结果
     * @param examRecordDataEntity
     * @return
     */
	CalculateFaceCheckResultInfo calculateFaceCheckResult(ExamRecordDataEntity examRecordDataEntity);

	/**
	 * 创建进行中的考试记录
	 * @param examRecordId
	 * @param examRecordDataId
	 * @param studentId
	 */
    void createExamingRecord(Long examRecordId, Long examRecordDataId, Long studentId, ExamType examType);

	/**
	 * 创建已交卷的考试记录
	 * @param examRecordId
	 * @param examRecordDataId
	 * @param studentId
	 */
	void createHandInExamRecord(Long examRecordId, Long examRecordDataId, Long studentId);

	/**
	 * 删除进行中考试记录id
	 * @param examRecordId
	 */
	void deleteExamingRecord(Long examRecordId);

    void deleteHandInExamRecord(Long examRecordId);

	/**
	 * 获取指定数量的考试中的数据
	 * @param startId
	 * @param limit
	 * @return
	 */
	List<ExamingRecordEntity> getLimitExamingRecords(Long startId, int limit);

	/**
	 * 获取指定数量的已交卷的考试数据
	 * @param startId
	 * @param limit
	 * @return
	 */
	List<HandInExamRecordEntity> getLimitHandInExamRecords(Long startId, int limit);

    /**
     * 计算活体检测结果
     * @param examRecordDataEntity
     */
	ExamRecordDataEntity calculateFaceLivenessVerifyResult(ExamRecordDataEntity examRecordDataEntity);
    
    /**
     * 创建离线考试记录
     * @param examRecord
     * @param fullyObjective
     * @return
     */
	ExamRecordDataEntity createOfflineExamRecordData(ExamRecordEntity examRecord, Boolean fullyObjective);
	
	/**
	 * 违纪自动审核
	 * @return
	 */
	ExamRecordDataEntity examRecordAutoAudit(Boolean isNoPhotoAndIllegality, ExamRecordDataEntity examRecordData);

	/**
	 * 考试记录是否已结束
	 * @param examRecordData 考试记录
	 * @return boolean
	 */
	boolean isExamRecordEnded(ExamRecordDataEntity examRecordData);

	/**
	 * 考试记录是否已结束
	 * @param examRecordDataId 考试记录id
	 * @return boolean
	 */
    boolean isExamRecordEnded(Long examRecordDataId);

}
